@@ -1,26 +1,20 @@
 # -*- coding: utf-8 -*-
 
-from django.conf import settings
-if 'localeurl' in settings.INSTALLED_APPS:
-    from localeurl.models import patch_reverse
-    patch_reverse()
-
-from bs4 import BeautifulSoup
 from datetime import datetime
 
+from django.conf import settings
 from django.contrib.contenttypes.models import ContentType
 from django.contrib.sites.models import Site
-from django.core.urlresolvers import reverse
+from django.test import override_settings
+from django.urls import reverse
 
 from model_mommy import mommy
 
 from coop_cms.models import NavNode, BaseArticle, ArticleCategory
-from coop_cms.settings import (
-    is_localized, get_article_class, get_article_templates, get_navtree_class, is_perm_middleware_installed,
-)
-from coop_cms.tests import BaseArticleTest, make_dt, AUTH_LOGIN_NAME
+from coop_cms.settings import has_localized_urls, get_article_class, get_article_templates, get_navtree_class
+from coop_cms.tests import BaseArticleTest, BeautifulSoup, make_dt
+
 
-    
 class ArticleTest(BaseArticleTest):
     
     def setUp(self):
@@ -30,17 +24,16 @@ class ArticleTest(BaseArticleTest):
             ('test/newsletter_red.html', 'Red'),
             ('test/newsletter_blue.html', 'Blue'),
         )
-        self._DJALOHA_LINK_MODELS = getattr(settings, 'DJALOHA_LINK_MODELS', [])
-        Article = get_article_class()
-        ct = ContentType.objects.get_for_model(Article)
-        settings.DJALOHA_LINK_MODELS = ['{0}.{1}'.format(ct.app_label, ct.model)]
+        self._HTML_EDITOR_LINK_MODELS = getattr(settings, 'HTML_EDITOR_LINK_MODELS', [])
+        article_class = get_article_class()
+        content_type = ContentType.objects.get_for_model(article_class)
+        settings.HTML_EDITOR_LINK_MODELS = ['{0}.{1}'.format(content_type.app_label, content_type.model)]
         
     def tearDown(self):
         super(ArticleTest, self).tearDown()
-        #restore
+        # restore
         settings.COOP_CMS_ARTICLE_TEMPLATES = self._default_article_templates
-        settings.DJALOHA_LINK_MODELS = self._DJALOHA_LINK_MODELS
-    
+        settings.HTML_EDITOR_LINK_MODELS = self._HTML_EDITOR_LINK_MODELS
 
     def _check_article(self, response, data):
         for (key, value) in data.items():
@@ -60,6 +53,12 @@ class ArticleTest(BaseArticleTest):
         self.assertEqual(article.slug, 'test')
         response = self.client.get(article.get_absolute_url())
         self.assertEqual(200, response.status_code)
+
+    def test_view_article_full_slug(self):
+        article = get_article_class().objects.create(title="When I am 64", publication=BaseArticle.PUBLISHED)
+        self.assertEqual(article.slug, 'when-i-am-64')
+        response = self.client.get(article.get_absolute_url())
+        self.assertEqual(200, response.status_code)
         
     def test_publication_flag_published(self):
         article = get_article_class().objects.create(title="test", publication=BaseArticle.PUBLISHED)
@@ -78,12 +77,27 @@ class ArticleTest(BaseArticleTest):
         self.assertEqual(article.is_draft(), True)
         url = article.get_absolute_url()
         response = self.client.get(url)
-        if is_perm_middleware_installed():
-            self.assertEqual(302, response.status_code)
-            auth_url = reverse(AUTH_LOGIN_NAME)
-            self.assertRedirects(response, auth_url+'?next='+url)
-        else:
-            self.assertEqual(403, response.status_code)
+        self.assertNotAllowed(response)
+
+    def test_login_required_authenticated(self):
+        """show page if permission required and authenticated"""
+        self._log_as_non_editor()
+        article = get_article_class().objects.create(
+            title="test", publication=BaseArticle.PUBLISHED, login_required=True
+        )
+        url = article.get_absolute_url()
+        response = self.client.get(url)
+        self.assertEqual(200, response.status_code)
+
+    def test_login_required_not_authenticated(self):
+        """raise permission denied if permission required not authenticated"""
+        self.client.logout()
+        article = get_article_class().objects.create(
+            title="test", publication=BaseArticle.PUBLISHED, login_required=True
+        )
+        url = article.get_absolute_url()
+        response = self.client.get(url)
+        self.assertNotAllowed(response)
         
     def test_404_ok(self):
         response = self.client.get("/jhjhjkahekhj", follow=True)
@@ -91,14 +105,14 @@ class ArticleTest(BaseArticleTest):
         
     def test_is_navigable(self):
         article = get_article_class().objects.create(title="test", publication=BaseArticle.PUBLISHED)
-        if is_localized():
+        if has_localized_urls():
             lang = settings.LANGUAGES[0][0]
             self.assertEqual('/{0}/test/'.format(lang), article.get_absolute_url())
         else:
             self.assertEqual('/test/', article.get_absolute_url())
 
     def test_create_slug(self):
-        article = get_article_class().objects.create(title=u"voici l'été", publication=BaseArticle.PUBLISHED)
+        article = get_article_class().objects.create(title="voici l'été", publication=BaseArticle.PUBLISHED)
         self.assertEqual(article.slug, 'voici-lete')
         response = self.client.get(article.get_absolute_url())
         self.assertEqual(200, response.status_code)
@@ -117,9 +131,71 @@ class ArticleTest(BaseArticleTest):
         response = self.client.post(article.get_edit_url(), data=data, follow=True)
         self.assertEqual(response.status_code, 200)
         self._check_article(response, data)
-        
+
+    def test_edit_article_html(self):
+        """It should save article correctly"""
+        article = get_article_class().objects.create(title="test", publication=BaseArticle.PUBLISHED)
+
+        data = {"title": 'salut', 'content': '<h2>Hello</h2><p>Hello</p>'}
+
+        self._log_as_editor()
+        response = self.client.post(article.get_edit_url(), data=data, follow=True)
+        self.assertEqual(response.status_code, 200)
+        self._check_article(response, data)
+
+    @override_settings(COOP_HTML_EDITOR='aloha')
+    def test_edit_article_html_with_br(self):
+        """It should save article correctly"""
+        article = get_article_class().objects.create(
+            title="test", publication=BaseArticle.PUBLISHED, template="test/standard.html"
+        )
+
+        data = {"title": 'salut', 'content': '<h2>Hello</h2><p>Hello<br>Cool<br /></p>'}
+
+        self._log_as_editor()
+        response = self.client.post(article.get_edit_url(), data=data, follow=True)
+
+        self.assertEqual(response.status_code, 200)
+        expected_content = '<h2>Hello</h2><p>Hello<br />Cool<br /></p>'
+        data['content'] = expected_content
+        self._check_article(response, data)
+
+    @override_settings(COOP_HTML_EDITOR='aloha')
+    def test_edit_article_html_with_img_wrapper(self):
+        """It should save article correctly"""
+        article = get_article_class().objects.create(
+            title="test", publication=BaseArticle.PUBLISHED, template="test/standard.html"
+        )
+
+        content = """
+            <p><div
+            contenteditable="false"
+            style="overflow: hidden; position: relative; display: inline-block; float: none;"
+            class="ui-wrapper aloha-image-box-active Aloha_Image_Resize aloha"
+            >
+                <img src="moby-dick.jpg" style="height: 207px; width: 269px;" class="ui-resizable" />
+                <div class="ui-resizable-handle ui-resizable-ne" style="z-index: 1000;"></div>
+                <div class="ui-resizable-handle ui-resizable-se ui-icon" style="z-index: 1000;"></div>
+                <div class="ui-resizable-handle ui-resizable-sw" style="z-index: 1000;"></div>
+                <div class="ui-resizable-handle ui-resizable-nw" style="z-index: 1000;"></div>
+            </div></p>
+        """
+
+        data = {"title": 'salut', 'content': content}
+
+        self._log_as_editor()
+        response = self.client.post(article.get_edit_url(), data=data, follow=True)
+
+        self.assertEqual(response.status_code, 200)
+
+        expected_content = '<p><img class="" src="moby-dick.jpg" style="height: 207px; width: 269px;"/></p>'
+        data['content'] = expected_content
+        self._check_article(response, data)
+
     def test_edit_article_draft(self):
-        article = get_article_class().objects.create(title="test", publication=BaseArticle.DRAFT)
+        article = get_article_class().objects.create(
+            title="test", publication=BaseArticle.DRAFT, template="test/standard.html"
+        )
         
         data = {"title": 'salut', 'content': 'bonjour!'}
         
@@ -168,22 +244,20 @@ class ArticleTest(BaseArticleTest):
         url = article.get_edit_url()
         data = {"title": 'salut', "content": 'oups'}
         response = self.client.post(url, data=data)
-        if is_perm_middleware_installed():
-            self.assertEqual(302, response.status_code)
-            auth_url = reverse(AUTH_LOGIN_NAME)
-            self.assertRedirects(response, auth_url+'?next='+url)
-        else:
-            self.assertEqual(403, response.status_code)
+        self.assertNotAllowed(response)
         
         article = get_article_class().objects.get(id=article.id)
         self.assertEquals(article.title, initial_data['title'])
         self.assertEquals(article.content, initial_data['content'])
         
-    def _is_aloha_found(self, response):
+    def check_inline_html_editor(self, response, is_loaded):
         self.assertEqual(200, response.status_code)
-        aloha_js = reverse('aloha_init')
-        content = unicode(response.content, 'utf-8')
-        return content.find(aloha_js) > 0
+        inline_editor_init_url = reverse('html_editor_init')
+
+        if is_loaded:
+            self.assertContains(response, inline_editor_init_url)
+        else:
+            self.assertNotContains(response, inline_editor_init_url)
         
     def test_edit_permission(self):
         initial_data = {'title': "ceci est un test", 'content': "this is my article content"}
@@ -193,36 +267,31 @@ class ArticleTest(BaseArticleTest):
         
         url = article.get_edit_url()
         response = self.client.get(url, follow=False)
-        if is_perm_middleware_installed():
-            self.assertEqual(302, response.status_code)
-            auth_url = reverse(AUTH_LOGIN_NAME)
-            self.assertRedirects(response, auth_url+'?next='+url)
-        else:
-            self.assertEqual(403, response.status_code)
+        self.assertNotAllowed(response)
     
         self._log_as_editor()
-        response = self.client.get(article.get_edit_url(), follow=False)#follow was TRue?
+        response = self.client.get(article.get_edit_url(), follow=False)
         self.assertEqual(200, response.status_code)
         
-    def test_aloha_loaded(self):
-        initial_data = {'title': u"ceci est un test", 'content': u"this is my article content"}
+    def test_inline_html_editor_loaded(self):
+        initial_data = {'title': "ceci est un test", 'content': "this is my article content"}
         article = get_article_class().objects.create(publication=BaseArticle.PUBLISHED, **initial_data)
         response = self.client.get(article.get_absolute_url())
-        self.assertFalse(self._is_aloha_found(response))
+        self.check_inline_html_editor(response, False)
         
         self._log_as_editor()
         response = self.client.get(article.get_edit_url())
-        self.assertTrue(self._is_aloha_found(response))
+        self.check_inline_html_editor(response, True)
         
-    def test_aloha_links(self):
+    def test_inline_html_editor_links(self):
         slugs = ("un", "deux", "trois", "quatre")
         for slug in slugs:
             get_article_class().objects.create(publication=BaseArticle.PUBLISHED, title=slug)
         initial_data = {'title': "test", 'content': "this is my article content"}
-        article = get_article_class().objects.create(**initial_data)
+        get_article_class().objects.create(**initial_data)
         
         self._log_as_editor()
-        response = self.client.get(reverse('aloha_init'))
+        response = self.client.get(reverse('html_editor_init'))
         
         context_slugs = [article.slug for article in response.context['links']]
         for slug in slugs:
@@ -233,12 +302,7 @@ class ArticleTest(BaseArticleTest):
         article = get_article_class().objects.create(title="test", publication=BaseArticle.DRAFT)
         url = article.get_absolute_url()
         response = self.client.get(url)
-        if is_perm_middleware_installed():
-            self.assertEqual(302, response.status_code)
-            auth_url = reverse(AUTH_LOGIN_NAME)
-            self.assertRedirects(response, auth_url+'?next='+url)
-        else:
-            self.assertEqual(403, response.status_code)
+        self.assertNotAllowed(response)
         
         self._log_as_editor()
         response = self.client.get(article.get_absolute_url())
@@ -257,7 +321,7 @@ class ArticleTest(BaseArticleTest):
         response = self.client.get(article.get_absolute_url())
         self.assertEqual(response.status_code, 200)
         
-        #checking html content would not work. Check that the article is updated
+        # checking html content would not work. Check that the article is updated
         for b in ['paul', 'georges', 'ringo', 'john']:
             self.assertContains(response, b)
 
@@ -305,7 +369,7 @@ class ArticleTest(BaseArticleTest):
             'title': "Un titre",
             'publication': BaseArticle.DRAFT,
             'template': get_article_templates(None, self.user)[0][0],
-            'navigation_parent': None,
+            'navigation_parent': '',
             'sites': [settings.SITE_ID]
         }
         
@@ -322,6 +386,46 @@ class ArticleTest(BaseArticleTest):
         self.assertEqual(NavNode.objects.count(), 0)
         self.assertEqual([a.id for a in article.sites.order_by("id")], data['sites'])
 
+    def test_view_new_article(self):
+        other_site = mommy.make(Site)
+
+        category1 = mommy.make(ArticleCategory)
+        category1.sites.clear()
+        category1.sites.add(Site.objects.get_current())
+        category1.save()
+
+        category2 = mommy.make(ArticleCategory)
+        category2.sites.clear()
+        category2.sites.add(Site.objects.get_current())
+        category2.sites.add(other_site)
+        category2.save()
+
+        category3 = mommy.make(ArticleCategory)
+        category3.sites.clear()
+        category3.sites.add(other_site)
+        category3.save()
+
+        category4 = mommy.make(ArticleCategory)
+        category4.sites.clear()
+        category4.save()
+
+        self._log_as_editor()
+
+        response = self.client.get(reverse('coop_cms_new_article'))
+        self.assertEqual(response.status_code, 200)
+        soup = BeautifulSoup(response.content)
+
+        categories_select_node = soup.select("select#id_category")[0]
+
+        categories = [node.text for node in categories_select_node.select('option')]
+
+        self.assertEqual(3, len(categories))
+        self.assertTrue('---------' in categories)
+        self.assertTrue(category1.name in categories)
+        self.assertTrue(category2.name in categories)
+        self.assertTrue(category3.name not in categories)
+        self.assertTrue(category4.name not in categories)
+
     def test_new_article_two_sites(self):
         other_site = mommy.make(Site)
         article_class = get_article_class()
@@ -331,7 +435,7 @@ class ArticleTest(BaseArticleTest):
             'title': "Un titre",
             'publication': BaseArticle.DRAFT,
             'template': get_article_templates(None, self.user)[0][0],
-            'navigation_parent': None,
+            'navigation_parent': '',
             'sites': sorted([settings.SITE_ID, other_site.id])
         }
 
@@ -346,8 +450,7 @@ class ArticleTest(BaseArticleTest):
         self.assertEqual(article.template, data['template'])
         self.assertEqual(article.navigation_parent, None)
         self.assertEqual(NavNode.objects.count(), 0)
-        self.assertEqual([a.id for a in article.sites.order_by("id")], data['sites'])
-
+        self.assertEqual([_article.id for _article in article.sites.order_by("id")], data['sites'])
 
     def test_new_article_without_site(self):
         article_class = get_article_class()
@@ -357,7 +460,7 @@ class ArticleTest(BaseArticleTest):
             'title': "Un titre",
             'publication': BaseArticle.DRAFT,
             'template': get_article_templates(None, self.user)[0][0],
-            'navigation_parent': None,
+            'navigation_parent': '',
             'sites': []
         }
 
@@ -377,7 +480,7 @@ class ArticleTest(BaseArticleTest):
             'title': "Un titre",
             'publication': BaseArticle.DRAFT,
             'template': get_article_templates(None, self.user)[0][0],
-            'navigation_parent': None,
+            'navigation_parent': '',
             'sites': [settings.SITE_ID, 999]
         }
 
@@ -389,6 +492,36 @@ class ArticleTest(BaseArticleTest):
         soup = BeautifulSoup(response.content)
         self.assertEqual(len(soup.select("ul.errorlist")), 1)
 
+    def test_new_article_invalid_category_site(self):
+        article_class = get_article_class()
+
+        category1 = mommy.make(ArticleCategory)
+        category1.sites.clear()
+        category1.sites.add(Site.objects.get_current())
+        category1.save()
+
+        category2 = mommy.make(ArticleCategory)
+        category2.sites.clear()
+        category2.save()
+
+        self._log_as_editor()
+        data = {
+            'title': "Un titre",
+            'category': category2.id,
+            'publication': BaseArticle.DRAFT,
+            'template': get_article_templates(None, self.user)[0][0],
+            'navigation_parent': '',
+            'sites': [settings.SITE_ID]
+        }
+
+        response = self.client.post(reverse('coop_cms_new_article'), data=data, follow=True)
+        self.assertEqual(response.status_code, 200)
+
+        self.assertEqual(article_class.objects.count(), 0)
+
+        soup = BeautifulSoup(response.content)
+        self.assertEqual(len(soup.select("ul.errorlist")), 1)
+
     def test_new_article_title_required(self):
         article_class = get_article_class()
 
@@ -397,7 +530,7 @@ class ArticleTest(BaseArticleTest):
             'title': "",
             'publication': BaseArticle.DRAFT,
             'template': get_article_templates(None, self.user)[0][0],
-            'navigation_parent': None,
+            'navigation_parent': '',
             'sites': [settings.SITE_ID]
         }
         
@@ -416,7 +549,7 @@ class ArticleTest(BaseArticleTest):
             'title': "Un titre",
             'publication': BaseArticle.PUBLISHED,
             'template': get_article_templates(None, self.user)[0][0],
-            'navigation_parent': None,
+            'navigation_parent': '',
             'sites': [settings.SITE_ID]
         }
         
@@ -441,15 +574,12 @@ class ArticleTest(BaseArticleTest):
             'title': "Ceci est un titre",
             'publication': BaseArticle.DRAFT,
             'template': get_article_templates(None, self.user)[0][0],
-            'navigation_parent': None,
+            'navigation_parent': '',
             'sites': [settings.SITE_ID]
         }
         
-        response = self.client.post(reverse('coop_cms_new_article'), data=data, follow=True)
-        self.assertEqual(200, response.status_code) #if can_edit returns 404 error
-        next_url = response.redirect_chain[-1][0]
-        login_url = reverse('django.contrib.auth.views.login')
-        self.assertTrue(login_url in next_url)
+        response = self.client.post(reverse('coop_cms_new_article'), data=data)
+        self.assertNotAllowed(response)
         
         self.assertEqual(article_class.objects.filter(title=data['title']).count(), 0)
         
@@ -461,12 +591,12 @@ class ArticleTest(BaseArticleTest):
             'title': "Ceci est un titre",
             'publication': BaseArticle.DRAFT,
             'template': get_article_templates(None, self.user)[0][0],
-            'navigation_parent': None,
+            'navigation_parent': '',
             'sites': [settings.SITE_ID]
         }
         
-        response = self.client.post(reverse('coop_cms_new_article'), data=data, follow=True)
-        self.assertEqual(403, response.status_code)
+        response = self.client.post(reverse('coop_cms_new_article'), data=data)
+        self.assertNotAllowed(response)
         self.assertEqual(article_class.objects.filter(title=data['title']).count(), 0)
         
     def test_new_article_navigation(self):
@@ -536,7 +666,7 @@ class ArticleTest(BaseArticleTest):
     def test_article_settings(self, move_nav=False):
         initial_data = {'title': "test", 'content': "this is my article content"}
         article_class = get_article_class()
-        art0 = mommy.make(article_class)
+        art0 = mommy.make(article_class, slug="art0" )
         
         art1 = article_class.objects.create(publication=BaseArticle.PUBLISHED, **initial_data)
         
@@ -580,7 +710,7 @@ class ArticleTest(BaseArticleTest):
         self.assertEqual(node.content_object, art1)
         self.assertEqual(node.parent, node1)
         
-        #Update the article
+        # Update the article
         category2 = mommy.make(ArticleCategory)
         
         node_id = node2.id if move_nav else node1.id
@@ -610,8 +740,7 @@ class ArticleTest(BaseArticleTest):
         self.assertEqual(art1.headline, data['headline'])
         self.assertEqual(art1.in_newsletter, data['in_newsletter'])
         self.assertEqual(art1.summary, data['summary'])
-        #self.assertEqual(art1.navigation_parent, data['navigation_parent'])
-        
+
         if move_nav:
             self.assertEqual(NavNode.objects.count(), 4)
             node = NavNode.objects.exclude(id__in=(node1.id, node2.id, node.id))[0]
@@ -643,7 +772,7 @@ class ArticleTest(BaseArticleTest):
             'headline': True,
             'in_newsletter': True,
             'summary': 'short summary',
-            'navigation_parent': None,
+            'navigation_parent': '',
             'sites': [settings.SITE_ID, other_site.id]
         }
 
@@ -673,7 +802,7 @@ class ArticleTest(BaseArticleTest):
             'headline': True,
             'in_newsletter': True,
             'summary': 'short summary',
-            'navigation_parent': None,
+            'navigation_parent': '',
             'sites': [settings.SITE_ID, 999]
         }
 
@@ -706,7 +835,7 @@ class ArticleTest(BaseArticleTest):
             'headline': True,
             'in_newsletter': True,
             'summary': 'short summary',
-            'navigation_parent': None,
+            'navigation_parent': '',
             'sites': []
         }
 
@@ -721,60 +850,3 @@ class ArticleTest(BaseArticleTest):
 
         self.assertNotEqual(art1.summary, data['summary'])
         self.assertEqual(sorted([a.id for a in art1.sites.all()]), [settings.SITE_ID])
-
-
-class TemplateTest(BaseArticleTest):
-    
-    def setUp(self):
-        super(TemplateTest, self).setUp()
-        self._default_article_templates = settings.COOP_CMS_ARTICLE_TEMPLATES
-        settings.COOP_CMS_ARTICLE_TEMPLATES = (
-            ('coop_cms/article.html', 'coop_cms base article'),
-            ('test/article.html', 'test article'),
-        )
-        
-    def tearDown(self):
-        super(TemplateTest, self).tearDown()
-        #restore
-        settings.COOP_CMS_ARTICLE_TEMPLATES = self._default_article_templates
-
-    def test_view_article(self):
-        #Check that we are do not using the PrivateArticle anymore
-        klass = get_article_class()
-        article = mommy.make(klass, publication=klass.PUBLISHED)
-        response = self.client.get(article.get_absolute_url())
-        self.assertTemplateUsed(response, 'coop_cms/article.html')
-        self.assertEqual(200, response.status_code)
-        
-    def test_view_article_custom_template(self):
-        #Check that we are do not using the PrivateArticle anymore
-        klass = get_article_class()
-        article = mommy.make(klass, publication=klass.PUBLISHED, template='test/article.html')
-        response = self.client.get(article.get_absolute_url())
-        self.assertTemplateUsed(response, 'test/article.html')
-        self.assertEqual(200, response.status_code)
-        
-    def test_change_template(self):
-        #Check that we are do not using the PrivateArticle anymore
-        klass = get_article_class()
-        article = mommy.make(klass)
-        self._log_as_editor()
-        url = reverse('coop_cms_change_template', args=[article.id])
-        response = self.client.post(url, data={'template': 'test/article.html'}, follow=True)
-        self.assertEqual(200, response.status_code)
-        article = klass.objects.get(id=article.id)#refresh
-        self.assertEqual(article.template, 'test/article.html')
-        
-    def test_change_template_permission(self):
-        #Check that we are do not using the PrivateArticle anymore
-        klass = get_article_class()
-        article = mommy.make(klass)
-        url = reverse('coop_cms_change_template', args=[article.id])
-        response = self.client.post(url, data={'template': 'test/article.html'}, follow=True)
-        self.assertEqual(200, response.status_code)
-        redirect_url = response.redirect_chain[-1][0]
-        login_url = reverse('django.contrib.auth.views.login')
-        self.assertTrue(redirect_url.find(login_url)>0)
-        article = klass.objects.get(id=article.id)#refresh
-        self.assertEqual(article.template, '')
-
